
# Slot: increases molecular interaction


indicates that the source increases the molecular interaction between the target and some other molecular entity

URI: [biolink:increases_molecular_interaction](https://w3id.org/biolink/vocab/increases_molecular_interaction)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [molecularly interacts with](molecularly_interacts_with.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | CTD:increases_molecular_interaction_with |

